@@ -1,11 +1,14 @@
 # -*- coding: utf-8 -*-
 
-miquire :boot, 'delayer'
-miquire :core, 'miquire_plugin'
+require 'boot/delayer'
+require 'miquire_plugin'
 
 using Miquire::ToSpec
 
-Miquire::Plugin.loadpath << Environment::PLUGIN_PATH << File.join(File.dirname(__FILE__), "..", "..", "plugin") << File.join(Environment::CONFROOT, 'plugin')
+Environment::PLUGIN_PATH.each do |path|
+  Miquire::Plugin.loadpath << path
+end
+Miquire::Plugin.loadpath << File.join(Environment::CONFROOT, 'plugin')
 
 writer = lambda do |spec|
   depends = Miquire::Plugin.depended_plugins(spec)
