@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 
-miquire :mui, 'timeline', 'tree_view_pretty_scroll', 'dark_matter_prification'
-miquire :lib, 'uithreadonly'
+require 'mui/cairo_timeline'
+require 'mui/gtk_dark_matter_prification'
+require 'mui/gtk_tree_view_pretty_scroll'
+
 require 'gtk2'
 
-class Gtk::TimeLine::InnerTL < Gtk::CRUD
+class Gtk::TimeLine::InnerTL < Gtk::CompatListView
 
-  include UiThreadOnly
   include Gtk::TreeViewPrettyScroll
   include Gtk::InnerTLDarkMatterPurification
 
@@ -77,13 +78,13 @@ class Gtk::TimeLine::InnerTL < Gtk::CRUD
   def handle_row_activated
   end
 
-  def create_postbox(options)
+  def create_postbox(options, &block)
     options = options.dup
     options[:before_post_hook] = ->(this) {
       get_ancestor(Gtk::Window).set_focus(self) unless self.destroyed? }
     pb = Gtk::PostBox.new(options).show_all
     postbox.closeup(pb)
-    pb.on_delete(&Proc.new) if block_given?
+    pb.on_delete(&block) if block
     get_ancestor(Gtk::Window).set_focus(pb.post)
     pb end
   private :create_postbox
@@ -111,10 +112,6 @@ class Gtk::TimeLine::InnerTL < Gtk::CRUD
       options[:postboxstorage] = postbox end
     create_postbox(options) end
 
-  def set_cursor_to_display_top
-    iter = model.iter_first
-    set_cursor(iter.path, get_column(0), false) if iter end
-
   def get_active_messages
     get_active_iterators.map{ |iter| iter[1] } end
 
