@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 # ／(^o^)＼
 
-require_relative '../utils'
-miquire :core, 'environment', 'serialthread', 'skin'
-miquire :mui, 'web_image_loader'
+require 'environment'
+require 'mui/gtk_web_image_loader'
+require 'serialthread'
+require 'skin'
 
 require 'gtk2'
 require 'observer'
@@ -30,9 +31,7 @@ module Gtk
       when GdkPixbuf::Pixbuf
         super(url)
       else
-        photo = Enumerator.new{|y|
-          Plugin.filtering(:photo_filter, url, y)
-        }.first
+        photo = Plugin.collect(:photo_filter, url, Pluggaloid::COLLECT).first
         super(load_model(photo || Skin[:notfound], rect))
       end
     end
